Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(28)

Unified Diff: chrome/browser/task_manager/sampling/task_manager_impl.h

Issue 2905403002: plumb network upload into the task manager (Closed)
Patch Set: added refresh timer tests Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/task_manager/sampling/task_manager_impl.h
diff --git a/chrome/browser/task_manager/sampling/task_manager_impl.h b/chrome/browser/task_manager/sampling/task_manager_impl.h
index b483494326c315aa64dd414f5d77358422e6d75f..fb3be153cc01406f60ebaa8635aea306b02e4168 100644
--- a/chrome/browser/task_manager/sampling/task_manager_impl.h
+++ b/chrome/browser/task_manager/sampling/task_manager_impl.h
@@ -74,7 +74,9 @@ class TaskManagerImpl : public TaskManagerInterface,
base::TerminationStatus* out_status,
int* out_error_code) const override;
int64_t GetNetworkUsage(TaskId task_id) const override;
+ int64_t GetCumulativeNetworkUsage(TaskId task_id) const override;
int64_t GetProcessTotalNetworkUsage(TaskId task_id) const override;
+ int64_t GetCumulativeProcessTotalNetworkUsage(TaskId task_id) const override;
int64_t GetSqliteMemoryUsed(TaskId task_id) const override;
bool GetV8Memory(TaskId task_id,
int64_t* allocated,
@@ -94,9 +96,10 @@ class TaskManagerImpl : public TaskManagerInterface,
void TaskRemoved(Task* task) override;
void TaskUnresponsive(Task* task) override;
// The notification method on the UI thread when multiple bytes are read
// from URLRequests. This will be called by the |io_thread_helper_|
- static void OnMultipleBytesReadUI(std::vector<BytesReadParam>* params);
+ static void OnMultipleBytesTransferedUI(
+ std::vector<BytesTransferedParam>* params);
private:
friend struct base::LazyInstanceTraitsBase<TaskManagerImpl>;
@@ -119,7 +122,7 @@ class TaskManagerImpl : public TaskManagerInterface,
// false otherwise, at which point the caller must explicitly match these
// bytes to the browser process by calling this method again with
// |param.origin_pid = 0| and |param.child_id = param.route_id = -1|.
- bool UpdateTasksWithBytesRead(const BytesReadParam& param);
+ bool UpdateTasksWithBytesTransfered(const BytesTransferedParam& param);
TaskGroup* GetTaskGroupByTaskId(TaskId task_id) const;
Task* GetTaskByTaskId(TaskId task_id) const;
@@ -94,9 +96,10 @@ class TaskManagerImpl : public TaskManagerInterface,
void TaskRemoved(Task* task) override;
void TaskUnresponsive(Task* task) override;
- // The notification method on the UI thread when multiple bytes are read
+ // The notification method on the UI thread when multiple bytes are transfered
// from URLRequests. This will be called by the |io_thread_helper_|

Powered by Google App Engine
This is Rietveld 408576698